function hh = makeBPF2( fd, N )
% makeBPF2 - design simple bandpass filter using firpm
%
% usage:
%   hh = makeBPF( fd, N )
%
% inputs:
%   fd - center frequency of pass band (normalized by fs)
%   N  - number of filter coefficients
%
% output:
%   hh - vector of filter coefficients

%% specify desired frequency response
% Consecutive DTMF frequencies are approximately 10% higher than their
% predecessors
ff = [0 0.9*fd 0.95*fd 1.05*fd 1.1*fd 0.5];
HH = [0 0 1 1 0 0];

%% impulse response via firpm
hh = firpm(N, ff*2, HH);
